using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BarcodeLib.Barcode.Linear;
using System.IO;
using BarcodeLib.Barcode;

namespace WinDemo
{
    public partial class LinearForm : Form
    {
        public LinearForm()
        {
            InitializeComponent();
        }

        private void LinearForm_Load(object sender, EventArgs e)
        {
            // init form controls value here
            ctrSymbology.SelectedIndex = 3;
            ctrAddCheckSum.SelectedIndex = 0;
            ctrRotate.SelectedIndex = 0;
            ctrFormat.SelectedIndex = 0;
            ctrBearerBars.SelectedIndex = 0;
            ctrShowText.SelectedIndex = 0;
            ctrCodabarStart.SelectedIndex = 0;
            ctrCodabarStop.SelectedIndex = 0;
            ctrUPCENumber.SelectedIndex = 0;

            ctrUOM.SelectedIndex = 0;


            bool validInputs = verifyInputs();
            if (validInputs)
                drawBarcode();
        }

        private void ctrBarcode_Load(object sender, EventArgs e)
        {
            
            ctrBarcode.Type = BarcodeLib.Barcode.Linear.BarcodeType.CODE39;
            ctrBarcode.Data = "1234567";
            ctrBarcode.ShowText = true;
            ctrBarcode.Refresh();
        }

        private void ctrDrawBarcode_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (validInputs)
                drawBarcode();
        }

        private bool verifyInputs()
        {
            string errorMessage = "";
            if (ctrData.Text.Trim().Equals(""))
            {
                errorMessage = "Barcode data cannot be empty.";
                ctrData.Focus();
            }

            try
            {
                float v = float.Parse(ctrBarWidth.Text);
                if (v <= 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for bar cell width.";
                ctrBarWidth.Focus();
            }
            try
            {
                float v = float.Parse(ctrBarHeight.Text);
                if (v <= 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for bar cell height.";
                ctrBarHeight.Focus();
            }

            try
            {
                float v = float.Parse(ctrLeftMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for left margin.";
                ctrLeftMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrTopMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for top margin.";
                ctrTopMargin.Focus();
            }
            try
            {
                int v = int.Parse(ctrResolution.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "int only for resolution.";
                ctrResolution.Focus();
            }

            if (!errorMessage.Equals(""))
            {
                MessageBox.Show(errorMessage);
                return false;
            }

            return true;
        }

        private void drawBarcode()
        {
            ctrBarcode.Type = EnumUtil.convertString2BarcodeType(ctrSymbology.Text);
            ctrBarcode.Data = ctrData.Text;
            ctrBarcode.SData = ctrSData.Text;

            ctrBarcode.ShowText = parseBool(ctrShowText.Text);
            ctrBarcode.TextFont = BarcodeUtils.parseFont(ctrTextFont.Text, Linear.DefaultTextFont);

            ctrBarcode.AddCheckSum = parseBool(ctrAddCheckSum.Text);
            ctrBarcode.Rotate = EnumUtil.convertString2RotateOrientation(ctrRotate.Text);
            ctrBarcode.Format = BarcodeUtils.convertString2ImageFormat(ctrFormat.Text, Linear.DefaultImageFormat);

            ctrBarcode.UOM = (UnitOfMeasure)ctrUOM.SelectedIndex;
            ctrBarcode.BarWidth = float.Parse(ctrBarWidth.Text);
            ctrBarcode.BarHeight = float.Parse(ctrBarHeight.Text);
            ctrBarcode.LeftMargin = float.Parse(ctrLeftMargin.Text);
            ctrBarcode.TopMargin = float.Parse(ctrTopMargin.Text);
            //  Add resolution here
            ctrBarcode.Resolution = int.Parse(ctrResolution.Text);

            ctrBarcode.BearerBars = getBearerBar();

            ctrBarcode.CodabarStartChar = EnumUtil.convertCodabarString2Enum(ctrCodabarStart.Text);
            ctrBarcode.CodabarStopChar = EnumUtil.convertCodabarString2Enum(ctrCodabarStop.Text);
            ctrBarcode.UPCENumberSystem = int.Parse(ctrUPCENumber.Text);

            ctrBarcode.Refresh();
        }

        private void ctrSaveImage_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (!validInputs)
                return;

            ctrSaveFileDialog.Filter = "GIF (*.gif)|*.gif|JPEG (*.jpg)|*.jpg|PNG (*.png)|*.png";
            ctrSaveFileDialog.FilterIndex = 1;

            if (ctrSaveFileDialog.ShowDialog() == DialogResult.OK)
            {
                drawBarcode();

                Stream imageStream = null;
                if ((imageStream = ctrSaveFileDialog.OpenFile()) != null)
                {
                    ctrBarcode.SaveAsImage(imageStream);
                    if (imageStream != null)
                        imageStream.Close();
                }
            }

        }

        private BearerBar getBearerBar()
        {
            if (ctrBearerBars.Text.Equals("None"))
            {
                return BearerBar.None;
            }
            else if (ctrBearerBars.Text.Equals("Frame"))
            {
                return BearerBar.Frame;
            }
            else if (ctrBearerBars.Text.Equals("TopBottom"))
            {
                return BearerBar.TopBottom;
            }

            return BearerBar.None;
        }

        private bool parseBool(string sbool)
        {
            if (sbool == null)
                return false;

            switch (sbool.ToLower())
            {
                case "yes":
                case "true":
                    return true;
            }

            return false;
        }

        private void ctrTextFontBrowse_Click(object sender, EventArgs e)
        {
            ctrFontDialog.ShowColor = false;
            ctrFontDialog.Font = ctrBarcode.TextFont;

            if (ctrFontDialog.ShowDialog() != DialogResult.Cancel)
            {
                ctrTextFont.Text = converFont2String(ctrFontDialog.Font);
            }
        }

        private string converFont2String(Font font)
        {
            if (font == null)
                return "";

            string text = ctrFontDialog.Font.Name + "|" + ctrFontDialog.Font.Size + "|";
            bool featured = false;
            if (ctrFontDialog.Font.Bold)
            {
                featured = true;
                text += "Bold ";
            }

            if (ctrFontDialog.Font.Italic)
            {
                featured = true;
                text += "Italic ";
            }

            if (ctrFontDialog.Font.Underline)
            {
                featured = true;
                text += "Underline ";
            }

            if (!featured)
            {
                text += "Regular";
            }
            return text;
        }

        

        private void button1_Click_1(object sender, EventArgs e)
        {
            base.Close();
        }

        private void ctrLeftMargin_TextChanged(object sender, EventArgs e)
        {

        }

        

        

        
        
    }
}