using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BarcodeLib.Barcode;
using System.Drawing.Imaging;
using System.IO;
using BarcodeLib.Barcode.Linear;

namespace WinDemo
{
    public partial class QRCodeForm : Form
    {
        public QRCodeForm()
        {
            InitializeComponent();
        }

        private void QRCodeForm_Load(object sender, EventArgs e)
        {
            ctrEncoding.SelectedIndex = 0;
            ctrVersion.SelectedIndex = 0;
            ctrECL.SelectedIndex = 0;
            ctrStructuredAppend.SelectedIndex = 1;
            ctrFNC1Mode.SelectedIndex = 0;
            ctrImageFormat.SelectedIndex = 0;
            ctrProcessTilde.SelectedIndex = 1;

            ctrUOM.SelectedIndex = 0;

            qrCode.Data = "BarcodeLib.com";
            qrCode.Refresh();
        }

        private void drawBarcode()
        {
            qrCode.Data = ctrData.Text;
            qrCode.Encoding = BarcodeUtils.convertString2QRCodeEncoding(ctrEncoding.Text);
            qrCode.Version = (BarcodeLib.Barcode.QRCode.QRCodeVersion)(ctrVersion.SelectedIndex);
            qrCode.ECL = (BarcodeLib.Barcode.QRCode.ErrorCorrectionLevel)(ctrECL.SelectedIndex);
            qrCode.EnableStructuredAppend = bool.Parse(ctrStructuredAppend.Text);
            qrCode.StructuredAppendCount = int.Parse(ctrStructuredAppendCount.Text);
            qrCode.StructuredAppendIndex = int.Parse(ctrStructuredAppendIndex.Text);
            qrCode.FNC1Mode = (BarcodeLib.Barcode.QRCode.QRCodeFNC1Mode)(ctrFNC1Mode.SelectedIndex);
            qrCode.ApplicationIndicator = byte.Parse(ctrApplicationIndicator.Text);
            qrCode.ECI = int.Parse(ctrECI.Text);
            qrCode.ProcessTilde = bool.Parse(ctrProcessTilde.Text);

            qrCode.UOM = (UnitOfMeasure)ctrUOM.SelectedIndex;
            qrCode.ModuleSize = float.Parse(ctrModuleSize.Text);
            qrCode.TopMargin = float.Parse(ctrTopMargin.Text);
            qrCode.LeftMargin = float.Parse(ctrLeftMargin.Text);
            qrCode.RightMargin = float.Parse(ctrRightMargin.Text);
            qrCode.BottomMargin = float.Parse(ctrBottomMargin.Text);

            //  Todo: Resolution
            qrCode.Resolution = int.Parse(ctrResolution.Text);

            qrCode.ImageFormat = BarcodeUtils.convertString2ImageFormat(ctrImageFormat.Text, ImageFormat.Gif); ;

            qrCode.Refresh();
        }

        private void ctrDrawBarcode_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (validInputs)
                drawBarcode();
        }

        private bool verifyInputs()
        {
            string errorMessage = "";
            if (ctrData.Text.Trim().Equals(""))
            {
                errorMessage = "Barcode data cannot be empty.";
                ctrData.Focus();
            }

            try
            {
                float v = float.Parse(ctrModuleSize.Text);
                if (v <= 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for module size.";
                ctrModuleSize.Focus();
            }
            try
            {
                float v = float.Parse(ctrLeftMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for left margin.";
                ctrLeftMargin.Focus();
            }

            try
            {
                float v = float.Parse(ctrRightMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for right margin.";
                ctrRightMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrTopMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for top margin.";
                ctrTopMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrBottomMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for bottom margin.";
                ctrBottomMargin.Focus();
            }

            try
            {
                int v = int.Parse(ctrResolution.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "int only for resolution.";
                ctrResolution.Focus();
            }

            if (ctrStructuredAppend.Text.Equals("True"))
            {
                try
                {
                    int v = int.Parse(ctrStructuredAppendCount.Text);
                    if (v <= 0)
                    {
                        throw new FormatException();
                    }
                }
                catch (System.FormatException e)
                {
                    errorMessage = "Append Count must be integer and greater than 0.";
                    ctrStructuredAppendCount.Focus();
                }
                try
                {
                    int v = int.Parse(ctrStructuredAppendIndex.Text);
                    if (v <= 0)
                    {
                        throw new FormatException();
                    }
                }
                catch (System.FormatException e)
                {
                    errorMessage = "Append Index must start with 1.";
                    ctrStructuredAppendIndex.Focus();
                }
            }

            try
            {
                int v = int.Parse(ctrApplicationIndicator.Text);
                if (v < 0 || v > 255)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "Application Indicator is from 0 to 255.";
                ctrApplicationIndicator.Focus();
            }

            try
            {

                int v = int.Parse(ctrECI.Text);
                if (v < -1 || v > 999999)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "ECI is from 0 to 999999, and -1 (not applied).";
                ctrECI.Focus();
            }

            if (!errorMessage.Equals(""))
            {
                MessageBox.Show(errorMessage);
                return false;
            }

            return true;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            base.Close();
        }

        private void ctrSaveImage_Click(object sender, EventArgs e)
        {
            //saveFileDialog1.Filter = "GIF (*.gif)|*.gif|JPEG (*.jpg)|*.jpg|PNG (*.png)|*.png";
            saveFileDialog1.Filter = "GIF (*.gif)|*.gif|JPEG (*.jpg)|*.jpg|BMP (*.bmp)|*.bmp";
            saveFileDialog1.FilterIndex = 1;

            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                drawBarcode();

                Stream imageStream = null;
                if ((imageStream = saveFileDialog1.OpenFile()) != null)
                {
                    qrCode.SaveAsImage(imageStream);
                    if (imageStream != null)
                        imageStream.Close();
                }
            }
        }

        
    }
}